@@ -141,9 +141,9 @@ class Config:
         Parameters:
             mode (Optional[str]): The job execution mode.
                 Possible values are: _"standalone"_ (the default value) or
-                _"airflow"_ (Enterprise version only).
-            nb_of_workers (Optional[int, str]): The maximum number of jobs able to run in
-                parallel. The default value is 1.<br/>
+                _"development"_.
+            nb_of_workers (Optional[int, str]): Parameter used only in default _"standalone"_ mode. The maximum
+                number of jobs able to run in parallel. The default value is 1.<br/>
                 A string can be provided to dynamically set the value using an environment
                 variable. The string must follow the pattern: `ENV[&lt;env_var&gt;]` where
                 `&lt;env_var&gt;` is the name of environment variable.
@@ -152,7 +152,7 @@ class Config:
         """
         job_config = JobConfig(
             mode,
-            nb_of_workers,
+            nb_of_workers=nb_of_workers,
             **properties,
         )
         cls._python_config._job_config = job_config
@@ -371,7 +371,7 @@ class Config:
         **properties,
     ) -> ScenarioConfig:
         """Configure a new scenario configuration made of a single new pipeline configuration.
-        
+
         A new pipeline configuration is created as well. If _pipeline_id_ is not provided,
         the new pipeline configuration identifier is set to the scenario configuration identifier
         post-fixed by '_pipeline'.
@@ -464,7 +464,7 @@ class Config:
     @classmethod
     def check(cls) -> IssueCollector:
         """Check configuration.
-        
+
         This method logs issue messages and returns an issue collector.
 
         Returns:
@@ -489,16 +489,16 @@ class Config:
     def configure_csv_data_node(
         cls,
         id: str,
-        path: str,
+        default_path: str = None,
         has_header: bool = True,
         scope=DataNodeConfig._DEFAULT_SCOPE,
-        **properties
+        **properties,
     ):
         """Configure a new CSV data node configuration.
 
         Parameters:
             id (str): The unique identifier of the new CSV data node configuration.
-            path (str): The path of the CSV file.
+            default_path (str): The default path of the CSV file.
             has_header (bool): If True, indicates that the CSV file has a header.
             scope (Scope^): The scope of the CSV data node configuration. The default value
                 is `Scope.SCENARIO`.
@@ -510,14 +510,14 @@ class Config:
         from taipy.core.data import CSVDataNode
 
         return cls.configure_data_node(
-            id, CSVDataNode.storage_type(), scope=scope, path=path, has_header=has_header, **properties
+            id, CSVDataNode.storage_type(), scope=scope, default_path=default_path, has_header=has_header, **properties
         )
 
     @classmethod
     def configure_excel_data_node(
         cls,
         id: str,
-        path: str,
+        default_path: str = None,
         has_header: bool = True,
         sheet_name: Union[List[str], str] = None,
         scope: Scope = DataNodeConfig._DEFAULT_SCOPE,
@@ -527,7 +527,7 @@ class Config:
 
         Parameters:
             id (str): The unique identifier of the new Excel data node configuration.
-            path (str): The path of the Excel file.
+            default_path (str): The path of the Excel file.
             has_header (bool): If True, indicates that the Excel file has a header.
             sheet_name (Union[List[str], str]): The list of sheet names to be used. This
                 can be a unique name.
@@ -544,7 +544,7 @@ class Config:
             id,
             ExcelDataNode.storage_type(),
             scope=scope,
-            path=path,
+            default_path=default_path,
             has_header=has_header,
             sheet_name=sheet_name,
             **properties,
